@@ -31,7 +31,7 @@ def isbn10_checksum(digits):
     reminder = sum(digit*coef for digit, coef in zip(map(int, digits), xrange(10, 1, -1))) % 11
     if reminder == 1: return 'X'
     return reminder and str(11 - reminder) or '0'
-    
+
 def isbn13_checksum(digits):
     if len(digits) != 12: raise ValueError
     reminder = sum(digit*coef for digit, coef in zip(map(int, digits), (1, 3)*6)) % 10
@@ -109,11 +109,11 @@ date_re_list = [ re.compile('^%s$'%s, re.UNICODE) for s in date_str_list ]
 time_str = r'(?P<hh>\d{1,2})(?:[:. ](?P<mm>\d{1,2})(?:[:. ](?P<ss>\d{1,2}))?)?\s*(?P<ampm>[ap][m])?'
 time_re = re.compile('^%s$'%time_str)
 
-datetime_re_list = [ re.compile('^%s(?: %s)?$' % (date_str, time_str), re.UNICODE) for date_str in date_str_list ]
+datetime_re_list = [ re.compile('^%s(?:[t ]%s)?$' % (date_str, time_str), re.UNICODE) for date_str in date_str_list ]
 
 month_lists = [
     "jan feb mar apr may jun jul aug sep oct nov dec".split(),
-    u"           ".split(),  # Russian 
+    u"           ".split(),  # Russian
     ]
 month_dict = {}
 
@@ -122,7 +122,7 @@ for month_list in month_lists:
         month_dict[month] = i + 1
 
 month_dict[u''] = 5  # Russian
-    
+
 def str2date(s):
     s = s.strip().lower()
     for date_re in date_re_list:
@@ -188,5 +188,5 @@ def str2py(value, type):
     try: return str2py(value)
     except ValidationError: raise
     except:
-        if value == '': return None 
+        if value == '': return None
         raise ValidationError(err_msg or 'Incorrect data')
