@@ -11,7 +11,7 @@ from MySQLdb.constants import FIELD_TYPE, FLAG, CLIENT
 
 from pony.orm import core, dbschema, dbapiprovider
 from pony.orm.core import log_orm, log_sql, OperationalError
-from pony.orm.dbapiprovider import DBAPIProvider, Pool, get_version_tuple
+from pony.orm.dbapiprovider import DBAPIProvider, Pool, get_version_tuple, wrap_dbapi_exceptions
 from pony.orm.sqltranslation import SQLTranslator
 from pony.orm.sqlbuilding import SQLBuilder, join
 from pony.utils import throw
@@ -54,10 +54,9 @@ class MySQLBuilder(SQLBuilder):
         return 'second(', builder(expr), ')'
 
 def _string_sql_type(converter):
-    db_encoding = converter.db_encoding or 'utf8'
-    if converter.max_len:
-        return 'VARCHAR(%d) CHARACTER SET %s' % (converter.max_len, db_encoding)
-    return 'LONGTEXT CHARACTER SET %s' % db_encoding
+    result = 'VARCHAR(%d)' % converter.max_len if converter.max_len else 'LONGTEXT'
+    if converter.db_encoding: result += ' CHARACTER SET %s' % converter.db_encoding
+    return result
 
 class MySQLUnicodeConverter(dbapiprovider.UnicodeConverter):
     sql_type = _string_sql_type
@@ -90,6 +89,7 @@ class MySQLProvider(DBAPIProvider):
     index_if_not_exists_syntax = False
     select_for_update_nowait_syntax = False
     max_time_precision = default_time_precision = 0
+    varchar_default_max_len = 255
 
     dbapi_module = MySQLdb
     dbschema_cls = MySQLSchema
@@ -110,6 +110,10 @@ class MySQLProvider(DBAPIProvider):
         (UUID, MySQLUuidConverter),
     ]
 
+    def normalize_name(provider, name):
+        return name[:provider.max_name_len].lower()
+
+    @wrap_dbapi_exceptions
     def inspect_connection(provider, connection):
         cursor = connection.cursor()
         cursor.execute('select version()')
@@ -137,44 +141,79 @@ class MySQLProvider(DBAPIProvider):
         kwargs['client_flag'] = kwargs.get('client_flag', 0) | CLIENT.FOUND_ROWS 
         return Pool(MySQLdb, *args, **kwargs)
 
-    def table_exists(provider, connection, table_name):
-        db_name, table_name = provider.split_table_name(table_name)
-        cursor = connection.cursor()
-        cursor.execute('SELECT 1 FROM information_schema.tables '
-                       'WHERE table_schema=%s and table_name=%s',
-                       [ db_name, table_name ])
-        return cursor.fetchone() is not None
-
-    def index_exists(provider, connection, table_name, index_name):
-        db_name, table_name = provider.split_table_name(table_name)
-        cursor = connection.cursor()
-        cursor.execute('SELECT 1 FROM information_schema.statistics '
-                       'WHERE table_schema=%s and table_name=%s and index_name=%s',
-                       [ db_name, table_name, index_name ])
-        return cursor.fetchone() is not None
-
-    def fk_exists(provider, connection, table_name, fk_name):
-        db_name, table_name = provider.split_table_name(table_name)
-        cursor = connection.cursor()
-        cursor.execute('SELECT 1 FROM information_schema.table_constraints '
-                       'WHERE table_schema=%s and table_name=%s '
-                       "and constraint_type='FOREIGN KEY' and constraint_name=%s",
-                       [ db_name, table_name, fk_name ])
-        return cursor.fetchone() is not None
-
-    def disable_fk_checks_if_necessary(provider, connection):
-        cursor = connection.cursor()
-        cursor.execute("SHOW VARIABLES LIKE 'foreign_key_checks'")
-        fk = cursor.fetchone()
-        if fk is not None: fk = (fk[1] == 'ON')
-        if fk: cursor.execute('SET foreign_key_checks = 0')
-        return bool(fk)
-
-    def enable_fk_checks_if_necessary(provider, connection, fk):
-        assert type(fk) is bool, fk
-        if fk:
+    @wrap_dbapi_exceptions
+    def set_transaction_mode(provider, connection, cache):
+        assert not cache.in_transaction
+        db_session = cache.db_session
+        if db_session is not None and db_session.ddl:
             cursor = connection.cursor()
-            cursor.execute('SET foreign_key_checks = 1')
+            cursor.execute("SHOW VARIABLES LIKE 'foreign_key_checks'")
+            fk = cursor.fetchone()
+            if fk is not None: fk = (fk[1] == 'ON')
+            if fk:
+                sql = 'SET foreign_key_checks = 0'
+                if core.debug: log_orm(sql)
+                cursor.execute(sql)
+            cache.saved_fk_state = bool(fk)
+            cache.in_transaction = True
+        cache.immediate = True
+        if db_session is not None and db_session.serializable:
+            cursor = connection.cursor()
+            sql = 'SET TRANSACTION ISOLATION LEVEL SERIALIZABLE'
+            if core.debug: log_orm(sql)
+            cursor.execute(sql)
+            cache.in_transaction = True
+
+    @wrap_dbapi_exceptions
+    def release(provider, connection, cache=None):
+        if cache is not None:
+            db_session = cache.db_session
+            if db_session is not None and db_session.ddl and cache.saved_fk_state:
+                try:
+                    cursor = connection.cursor()
+                    sql = 'SET foreign_key_checks = 1'
+                    if core.debug: log_orm(sql)
+                    cursor.execute(sql)
+                except:
+                    provider.pool.drop(connection)
+                    raise
+        DBAPIProvider.release(provider, connection, cache)
+
+
+    def table_exists(provider, connection, table_name, case_sensitive=True):
+        db_name, table_name = provider.split_table_name(table_name)
+        cursor = connection.cursor()
+        if case_sensitive: sql = 'SELECT table_name FROM information_schema.tables ' \
+                                 'WHERE table_schema=%s and table_name=%s'
+        else: sql = 'SELECT table_name FROM information_schema.tables ' \
+                    'WHERE table_schema=%s and UPPER(table_name)=UPPER(%s)'
+        cursor.execute(sql, [ db_name, table_name ])
+        row = cursor.fetchone()
+        return row[0] if row is not None else None
+
+    def index_exists(provider, connection, table_name, index_name, case_sensitive=True):
+        db_name, table_name = provider.split_table_name(table_name)
+        if case_sensitive: sql = 'SELECT index_name FROM information_schema.statistics ' \
+                                 'WHERE table_schema=%s and table_name=%s and index_name=%s'
+        else: sql = 'SELECT index_name FROM information_schema.statistics ' \
+                    'WHERE table_schema=%s and table_name=%s and UPPER(index_name)=UPPER(%s)'
+        cursor = connection.cursor()
+        cursor.execute(sql, [ db_name, table_name, index_name ])
+        row = cursor.fetchone()
+        return row[0] if row is not None else None
+
+    def fk_exists(provider, connection, table_name, fk_name, case_sensitive=True):
+        db_name, table_name = provider.split_table_name(table_name)
+        if case_sensitive: sql = 'SELECT constraint_name FROM information_schema.table_constraints ' \
+                                 'WHERE table_schema=%s and table_name=%s ' \
+                                 "and constraint_type='FOREIGN KEY' and constraint_name=%s"
+        else: sql = 'SELECT constraint_name FROM information_schema.table_constraints ' \
+                    'WHERE table_schema=%s and table_name=%s ' \
+                    "and constraint_type='FOREIGN KEY' and UPPER(constraint_name)=UPPER(%s)"
+        cursor = connection.cursor()
+        cursor.execute(sql, [ db_name, table_name, fk_name ])
+        row = cursor.fetchone()
+        return row[0] if row is not None else None
 
 provider_cls = MySQLProvider
 
