@@ -32,70 +32,70 @@ class TestOneToOne(unittest.TestCase):
     def test_1(self):
         Male[3].wife = Female[3]
 
-        self.assertEqual(Male[3]._vals_['wife'], Female[3])
-        self.assertEqual(Female[3]._vals_['husband'], Male[3])
+        self.assertEqual(Male[3]._vals_[Male.wife], Female[3])
+        self.assertEqual(Female[3]._vals_[Female.husband], Male[3])
         commit()
         wives = db.select('wife from Male order by Male.id')
         self.assertEqual([1, 2, 3], wives)
     def test_2(self):
         Female[3].husband = Male[3]
 
-        self.assertEqual(Male[3]._vals_['wife'], Female[3])
-        self.assertEqual(Female[3]._vals_['husband'], Male[3])
+        self.assertEqual(Male[3]._vals_[Male.wife], Female[3])
+        self.assertEqual(Female[3]._vals_[Female.husband], Male[3])
         commit()
         wives = db.select('wife from Male order by Male.id')
         self.assertEqual([1, 2, 3], wives)
     def test_3(self):
         Male[1].wife = None
 
-        self.assertEqual(Male[1]._vals_['wife'], None)
-        self.assertEqual(Female[1]._vals_['husband'], None)
+        self.assertEqual(Male[1]._vals_[Male.wife], None)
+        self.assertEqual(Female[1]._vals_[Female.husband], None)
         commit()
         wives = db.select('wife from Male order by Male.id')
         self.assertEqual([None, 2, None], wives)
     def test_4(self):
         Female[1].husband = None
 
-        self.assertEqual(Male[1]._vals_['wife'], None)
-        self.assertEqual(Female[1]._vals_['husband'], None)
+        self.assertEqual(Male[1]._vals_[Male.wife], None)
+        self.assertEqual(Female[1]._vals_[Female.husband], None)
         commit()
         wives = db.select('wife from Male order by Male.id')
         self.assertEqual([None, 2, None], wives)
     def test_5(self):
         Male[1].wife = Female[3]
 
-        self.assertEqual(Male[1]._vals_['wife'], Female[3])
-        self.assertEqual(Female[1]._vals_['husband'], None)
-        self.assertEqual(Female[3]._vals_['husband'], Male[1])
+        self.assertEqual(Male[1]._vals_[Male.wife], Female[3])
+        self.assertEqual(Female[1]._vals_[Female.husband], None)
+        self.assertEqual(Female[3]._vals_[Female.husband], Male[1])
         commit()
         wives = db.select('wife from Male order by Male.id')
         self.assertEqual([3, 2, None], wives)
     def test_6(self):
         Female[3].husband = Male[1]
 
-        self.assertEqual(Male[1]._vals_['wife'], Female[3])
-        self.assertEqual(Female[1]._vals_['husband'], None)
-        self.assertEqual(Female[3]._vals_['husband'], Male[1])
+        self.assertEqual(Male[1]._vals_[Male.wife], Female[3])
+        self.assertEqual(Female[1]._vals_[Female.husband], None)
+        self.assertEqual(Female[3]._vals_[Female.husband], Male[1])
         commit()
         wives = db.select('wife from Male order by Male.id')
         self.assertEqual([3, 2, None], wives)
     def test_7(self):
         Male[1].wife = Female[2]
 
-        self.assertEqual(Male[1]._vals_['wife'], Female[2])
-        self.assertEqual(Male[2]._vals_['wife'], None)
-        self.assertEqual(Female[1]._vals_['husband'], None)
-        self.assertEqual(Female[2]._vals_['husband'], Male[1])
+        self.assertEqual(Male[1]._vals_[Male.wife], Female[2])
+        self.assertEqual(Male[2]._vals_[Male.wife], None)
+        self.assertEqual(Female[1]._vals_[Female.husband], None)
+        self.assertEqual(Female[2]._vals_[Female.husband], Male[1])
         commit()
         wives = db.select('wife from Male order by Male.id')
         self.assertEqual([2, None, None], wives)
     def test_8(self):
         Female[2].husband = Male[1]
 
-        self.assertEqual(Male[1]._vals_['wife'], Female[2])
-        self.assertEqual(Male[2]._vals_['wife'], None)
-        self.assertEqual(Female[1]._vals_['husband'], None)
-        self.assertEqual(Female[2]._vals_['husband'], Male[1])
+        self.assertEqual(Male[1]._vals_[Male.wife], Female[2])
+        self.assertEqual(Male[2]._vals_[Male.wife], None)
+        self.assertEqual(Female[1]._vals_[Female.husband], None)
+        self.assertEqual(Female[2]._vals_[Female.husband], Male[1])
         commit()
         wives = db.select('wife from Male order by Male.id')
         self.assertEqual([2, None, None], wives)
